"""Main entrypoint for the gptsum package.

Simply invokes :func:`gptsum.cli.main`.
"""
import gptsum.cli

if __name__ == "__main__":
    gptsum.cli.main()
